@@ -3,13 +3,11 @@ from future.standard_library import install_aliases  # isort:skip
 install_aliases()  # isort:skip
 
 import signal
+import threading
+import warnings
 
 import click
 import requests
-from graphql import graphql
-from graphql.execution.executors.gevent import GeventExecutor
-from graphql.execution.executors.sync import SyncExecutor
-
 from dagster import check, seven
 from dagster.cli.workspace import workspace_target_argument
 from dagster.cli.workspace.cli_target import WORKSPACE_TARGET_WARNING, get_workspace_from_kwargs
@@ -18,8 +16,11 @@ from dagster.core.instance import DagsterInstance
 from dagster.seven import urljoin, urlparse
 from dagster.utils import DEFAULT_REPOSITORY_YAML_FILENAME
 from dagster.utils.log import get_stack_trace_array
+from graphql import graphql
+from graphql.execution.executors.gevent import GeventExecutor
+from graphql.execution.executors.sync import SyncExecutor
 
-from .client.query import EXECUTE_PLAN_MUTATION, LAUNCH_PIPELINE_EXECUTION_MUTATION
+from .client.query import LAUNCH_PIPELINE_EXECUTION_MUTATION
 from .implementation.context import DagsterGraphQLContext
 from .schema import create_schema
 from .version import __version__
@@ -126,7 +127,6 @@ def execute_query_against_remote(host, query, variables):
 
 
 PREDEFINED_QUERIES = {
-    "executePlan": EXECUTE_PLAN_MUTATION,
     "launchPipelineExecution": LAUNCH_PIPELINE_EXECUTION_MUTATION,
 }
 
@@ -139,7 +139,7 @@ PREDEFINED_QUERIES = {
         "\n\n{warning}".format(warning=WORKSPACE_TARGET_WARNING)
     )
     + (
-        "\n\n Examples:"
+        "\n\nExamples:"
         "\n\n1. dagster-graphql"
         "\n\n2. dagster-graphql -y path/to/{default_filename}"
         "\n\n3. dagster-graphql -f path/to/file.py -a define_repo"
@@ -198,7 +198,16 @@ def ui(text, file, predefined, variables, remote, output, remap_sigterm, **kwarg
         )
 
     if remap_sigterm:
-        signal.signal(signal.SIGTERM, signal.getsignal(signal.SIGINT))
+        try:
+            signal.signal(signal.SIGTERM, signal.getsignal(signal.SIGINT))
+        except ValueError:
+            warnings.warn(
+                (
+                    "Unexpected error attempting to manage signal handling on thread {thread_name}. "
+                    "You should not invoke this API (execute_run_with_structured_logs) from threads "
+                    "other than the main thread."
+                ).format(thread_name=threading.current_thread().name)
+            )
 
     if remote:
         res = execute_query_against_remote(remote, query, variables)
