@@ -1,25 +1,28 @@
-from dagster_graphql.implementation.utils import UserFacingGraphQLError
-from dagster_graphql.schema.errors import DauphinInvalidSubsetError
-from dagster_graphql.schema.pipelines import DauphinPipeline
-
 from dagster import check
 from dagster.core.host_representation import PipelineSelector, RepositoryLocation
 from dagster.core.host_representation.external import ExternalPipeline
 from dagster.core.instance import DagsterInstance
+from dagster.grpc.types import ScheduleExecutionDataMode
+from dagster_graphql.implementation.utils import UserFacingGraphQLError
+from dagster_graphql.schema.errors import DauphinInvalidSubsetError
+from dagster_graphql.schema.pipelines import DauphinPipeline
 
 
 class DagsterGraphQLContext:
-    def __init__(self, instance, locations, version=None):
-        self._instance = check.inst_param(instance, 'instance', DagsterInstance)
+    def __init__(self, instance, workspace, version=None):
+        self._instance = check.inst_param(instance, "instance", DagsterInstance)
+        self._workspace = workspace
         self._repository_locations = {}
-        for loc in check.list_param(locations, 'locations', RepositoryLocation):
+        for handle in self._workspace.repository_location_handles:
             check.invariant(
-                self._repository_locations.get(loc.name) is None,
+                self._repository_locations.get(handle.location_name) is None,
                 'Can not have multiple locations with the same name, got multiple "{name}"'.format(
-                    name=loc.name
+                    name=handle.location_name,
                 ),
             )
-            self._repository_locations[loc.name] = loc
+            self._repository_locations[handle.location_name] = RepositoryLocation.from_handle(
+                handle
+            )
         self.version = version
 
     @property
@@ -37,12 +40,14 @@ class DagsterGraphQLContext:
         return name in self._repository_locations
 
     def reload_repository_location(self, name):
-        new_location = self._repository_locations[name].create_reloaded_repository_location()
+        new_handle = self._workspace.reload_repository_location(name)
+        new_location = RepositoryLocation.from_handle(new_handle)
+        check.invariant(new_location.name == name)
         self._repository_locations[name] = new_location
         return new_location
 
     def get_subset_external_pipeline(self, selector):
-        check.inst_param(selector, 'selector', PipelineSelector)
+        check.inst_param(selector, "selector", PipelineSelector)
         # We have to grab the pipeline from the location instead of the repository directly
         # since we may have to request a subset we don't have in memory yet
 
@@ -69,7 +74,7 @@ class DagsterGraphQLContext:
         )
 
     def has_external_pipeline(self, selector):
-        check.inst_param(selector, 'selector', PipelineSelector)
+        check.inst_param(selector, "selector", PipelineSelector)
         if selector.location_name in self._repository_locations:
             loc = self._repository_locations[selector.location_name]
             if loc.has_repository(selector.repository_name):
@@ -122,30 +127,22 @@ class DagsterGraphQLContext:
     def get_external_schedule_execution_data(self, repository_handle, schedule_name):
         return self._repository_locations[
             repository_handle.repository_location_handle.location_name
-        ].get_external_schedule_execution_data(self.instance, repository_handle, schedule_name)
+        ].get_external_schedule_execution_data(
+            self.instance, repository_handle, schedule_name, ScheduleExecutionDataMode.PREVIEW, None
+        )
 
-    def execute_plan(
-        self, external_pipeline, run_config, pipeline_run, step_keys_to_execute, retries=None
+    def get_external_job_param_data(self, repository_handle, job_name):
+        return self._repository_locations[
+            repository_handle.repository_location_handle.location_name
+        ].get_external_job_params(self.instance, repository_handle, job_name)
+
+    def get_external_partition_set_execution_param_data(
+        self, repository_handle, partition_set_name, partition_names
     ):
-        return self._repository_locations[external_pipeline.handle.location_name].execute_plan(
-            instance=self.instance,
-            external_pipeline=external_pipeline,
-            run_config=run_config,
-            pipeline_run=pipeline_run,
-            step_keys_to_execute=step_keys_to_execute,
-            retries=retries,
+        return self._repository_locations[
+            repository_handle.repository_location_handle.location_name
+        ].get_external_partition_set_execution_param_data(
+            repository_handle=repository_handle,
+            partition_set_name=partition_set_name,
+            partition_names=partition_names,
         )
-
-    def execute_pipeline(self, external_pipeline, pipeline_run):
-        return self._repository_locations[external_pipeline.handle.location_name].execute_pipeline(
-            instance=self.instance, external_pipeline=external_pipeline, pipeline_run=pipeline_run
-        )
-
-    def drain_outstanding_executions(self):
-        '''
-        This ensures that any outstanding executions of runs are waited on.
-        Useful for tests contexts when you want to ensure a started run
-        has ended in order to verify its results.
-        '''
-        if self.instance.run_launcher:
-            self.instance.run_launcher.join()
