@@ -1,7 +1,5 @@
 from __future__ import absolute_import
 
-from dagster_graphql import dauphin
-
 from dagster import check
 from dagster.config.errors import (
     EvaluationError,
@@ -16,10 +14,10 @@ from dagster.config.stack import EvaluationStackListItemEntry, EvaluationStackPa
 from dagster.core.host_representation import RepresentedPipeline
 from dagster.core.snap import ConfigSchemaSnapshot
 from dagster.utils.error import SerializableErrorInfo
+from dagster_graphql import dauphin
 
 from ..implementation.utils import PipelineSelector
 from .config_types import DauphinConfigTypeField
-from .runs import DauphinStepEvent
 
 
 class DauphinError(dauphin.Interface):
@@ -519,28 +517,6 @@ class DauphinLaunchPipelineExecutionResult(dauphin.Union):
         types = launch_pipeline_run_result_types + pipeline_execution_error_types
 
 
-class DauphinExecutePlanSuccess(dauphin.ObjectType):
-    class Meta(object):
-        name = "ExecutePlanSuccess"
-
-    pipeline = dauphin.Field(dauphin.NonNull("Pipeline"))
-    has_failures = dauphin.Field(dauphin.NonNull(dauphin.Boolean))
-    step_events = dauphin.non_null_list(DauphinStepEvent)
-    raw_event_records = dauphin.non_null_list(dauphin.String)
-
-
-class DauphinExecutePlanResult(dauphin.Union):
-    class Meta(object):
-        name = "ExecutePlanResult"
-        types = (
-            DauphinExecutePlanSuccess,
-            DauphinPipelineConfigValidationInvalid,
-            DauphinPipelineNotFoundError,
-            DauphinInvalidStepError,
-            DauphinPythonError,
-        )
-
-
 class DauphinLaunchPipelineReexecutionResult(dauphin.Union):
     class Meta(object):
         name = "LaunchPipelineReexecutionResult"
