@@ -1,11 +1,23 @@
 import sys
 
+from dagster import check
+from dagster.core.definitions.events import AssetKey
+from dagster.core.execution.retries import Retries
+from dagster.core.host_representation import (
+    RepositorySelector,
+    RepresentedPipeline,
+    ScheduleSelector,
+    TriggerSelector,
+)
+from dagster.core.instance import DagsterInstance
+from dagster.core.launcher import RunLauncher
+from dagster.core.storage.compute_log_manager import ComputeIOType
+from dagster.core.storage.pipeline_run import PipelineRunStatus, PipelineRunsFilter
 from dagster_graphql import dauphin
 from dagster_graphql.implementation.execution import (
     ExecutionParams,
     create_and_launch_partition_backfill,
     delete_pipeline_run,
-    do_execute_plan,
     get_compute_log_observable,
     get_pipeline_run_observable,
     launch_pipeline_execution,
@@ -54,20 +66,6 @@ from dagster_graphql.implementation.utils import (
     pipeline_selector_from_graphql,
 )
 
-from dagster import check
-from dagster.core.definitions.events import AssetKey
-from dagster.core.execution.retries import Retries
-from dagster.core.host_representation import (
-    RepositorySelector,
-    RepresentedPipeline,
-    ScheduleSelector,
-    TriggerSelector,
-)
-from dagster.core.instance import DagsterInstance
-from dagster.core.launcher import RunLauncher
-from dagster.core.storage.compute_log_manager import ComputeIOType
-from dagster.core.storage.pipeline_run import PipelineRunStatus, PipelineRunsFilter
-
 from .config_types import to_dauphin_config_type
 from .runs import DauphinPipelineRunStatus
 from .schedules import (
@@ -622,17 +620,6 @@ def create_execution_metadata(graphql_execution_metadata):
     )
 
 
-@capture_dauphin_error
-def create_execution_params_and_do_exec_plan(graphene_info, execution_params_dict, retries_dict):
-    # refactored into a helper function here in order to wrap with @capture_dauphin_error,
-    # because create_execution_params may raise
-    return do_execute_plan(
-        graphene_info,
-        execution_params=create_execution_params(graphene_info, execution_params_dict),
-        retries=create_retries_params(retries_dict),
-    )
-
-
 class DauphinRetriesPreviousAttempts(dauphin.InputObjectType):
     class Meta(object):
         name = "RetriesPreviousAttempts"
@@ -653,24 +640,6 @@ def create_retries_params(retries_config):
     return Retries.from_graphql_input(retries_config)
 
 
-class DauphinExecutePlan(dauphin.Mutation):
-    class Meta(object):
-        name = "ExecutePlan"
-
-    class Arguments(object):
-        executionParams = dauphin.NonNull("ExecutionParams")
-        retries = dauphin.Argument("Retries")
-
-    Output = dauphin.NonNull("ExecutePlanResult")
-
-    def mutate(self, graphene_info, **kwargs):
-        return create_execution_params_and_do_exec_plan(
-            graphene_info,
-            execution_params_dict=kwargs["executionParams"],
-            retries_dict=kwargs["retries"] if "retries" in kwargs else None,
-        )
-
-
 class DauphinTriggerExecution(dauphin.Mutation):
     class Meta(object):
         name = "TriggerExecution"
@@ -701,15 +670,6 @@ class DauphinMutation(dauphin.ObjectType):
     launch_partition_backfill = DauphinLaunchPartitionBackfillMutation.Field()
     trigger_execution = DauphinTriggerExecution.Field()
 
-    # These below are never invoked by tools such as a dagit. They are in the
-    # graphql layer because it was a convenient, pre-existing IPC layer.
-    # so that components like run launchers and integrations with systems
-    # like airflow could invoke runs and subplans across a process boundary.
-    # They will eventually move to our "cli api" or its successor (possibly
-    # grpc).
-
-    execute_plan = DauphinExecutePlan.Field()
-
 
 DauphinComputeIOType = dauphin.Enum.from_enum(ComputeIOType)
 
@@ -829,7 +789,7 @@ class DauphinTriggerSelector(dauphin.InputObjectType):
 
     repositoryName = dauphin.NonNull(dauphin.String)
     repositoryLocationName = dauphin.NonNull(dauphin.String)
-    executableName = dauphin.NonNull(dauphin.String)
+    jobName = dauphin.NonNull(dauphin.String)
 
 
 class DauphinPartitionBackfillParams(dauphin.InputObjectType):
