@@ -6,13 +6,6 @@ import time
 from collections import OrderedDict
 from copy import deepcopy
 
-from dagster_graphql.implementation.context import DagsterGraphQLContext
-from dagster_graphql.test.utils import (
-    define_context_for_file,
-    define_out_of_process_context,
-    infer_pipeline_selector,
-)
-
 from dagster import (
     Any,
     AssetMaterialization,
@@ -52,14 +45,23 @@ from dagster import (
     usable_as_dagster_type,
     weekly_schedule,
 )
-from dagster.cli.workspace import Workspace
-from dagster.core.definitions.decorators import executable
+from dagster.cli.workspace.load import location_handle_from_python_file
+from dagster.core.definitions.decorators import job
 from dagster.core.definitions.partition import last_empty_partition
 from dagster.core.definitions.reconstructable import ReconstructableRepository
-from dagster.core.host_representation import InProcessRepositoryLocation, RepositoryLocationHandle
+from dagster.core.host_representation import RepositoryLocation
+from dagster.core.host_representation.handle import python_user_process_api_from_instance
 from dagster.core.log_manager import coerce_valid_log_level
 from dagster.core.storage.tags import RESUME_RETRY_TAG
+from dagster.core.test_utils import today_at_midnight
 from dagster.utils import file_relative_path, segfault
+from dagster_graphql.test.utils import (
+    define_in_process_context,
+    define_out_of_process_context,
+    infer_pipeline_selector,
+    main_repo_location_name,
+    main_repo_name,
+)
 
 
 @dagster_type_loader(String)
@@ -88,41 +90,28 @@ PoorMansDataFrame = PythonObjectDagsterType(
 
 def define_test_out_of_process_context(instance):
     check.inst_param(instance, "instance", DagsterInstance)
-    return define_out_of_process_context(__file__, "test_repo", instance)
+    return define_out_of_process_context(__file__, main_repo_name(), instance)
 
 
-def define_test_context(instance):
+def define_test_in_process_context(instance):
     check.inst_param(instance, "instance", DagsterInstance)
-    return define_context_for_file(__file__, "test_repo", instance)
+    return define_in_process_context(__file__, main_repo_name(), instance)
 
 
 def create_main_recon_repo():
-    return ReconstructableRepository.for_file(__file__, "test_repo")
+    return ReconstructableRepository.for_file(__file__, main_repo_name())
 
 
-def get_main_external_repo():
-    return InProcessRepositoryLocation(
-        ReconstructableRepository.from_legacy_repository_yaml(
-            file_relative_path(__file__, "repo.yaml")
-        ),
-    ).get_repository("test_repo")
-
-
-def define_test_snapshot_context():
-    return DagsterGraphQLContext(
-        instance=DagsterInstance.ephemeral(),
-        workspace=Workspace(
-            [RepositoryLocationHandle.create_in_process_location(create_main_recon_repo().pointer)]
-        ),
-    )
-
-
-def main_repo_location_name():
-    return "<<in_process>>"
-
-
-def main_repo_name():
-    return "test_repo"
+def get_main_external_repo(instance):
+    return RepositoryLocation.from_handle(
+        location_handle_from_python_file(
+            python_file=file_relative_path(__file__, "setup.py"),
+            attribute=main_repo_name(),
+            working_directory=None,
+            user_process_api=python_user_process_api_from_instance(instance),
+            location_name=main_repo_location_name(),
+        )
+    ).get_repository(main_repo_name())
 
 
 @lambda_solid(
@@ -303,7 +292,7 @@ def more_complicated_nested_config():
     def a_solid_with_multilayered_config(_):
         return None
 
-    return a_solid_with_multilayered_config()
+    a_solid_with_multilayered_config()
 
 
 @pipeline(
@@ -333,7 +322,7 @@ def more_complicated_nested_config():
     ]
 )
 def csv_hello_world():
-    return sum_sq_solid(sum_df=sum_solid())
+    sum_sq_solid(sum_df=sum_solid())
 
 
 @pipeline
@@ -345,7 +334,7 @@ def csv_hello_world_with_expectations():
 
 @pipeline
 def csv_hello_world_two():
-    return sum_solid()
+    sum_solid()
 
 
 @solid
@@ -355,7 +344,7 @@ def solid_that_gets_tags(context):
 
 @pipeline(tags={"tag_key": "tag_value"})
 def hello_world_with_tags():
-    return solid_that_gets_tags()
+    solid_that_gets_tags()
 
 
 @solid(name="solid_with_list", input_defs=[], output_defs=[], config_schema=[int])
@@ -370,7 +359,7 @@ def pipeline_with_list():
 
 @pipeline
 def csv_hello_world_df_input():
-    return sum_sq_solid(sum_solid())
+    sum_sq_solid(sum_solid())
 
 
 @pipeline
@@ -379,7 +368,7 @@ def no_config_pipeline():
     def return_hello():
         return "Hello"
 
-    return return_hello()
+    return_hello()
 
 
 @pipeline
@@ -392,7 +381,7 @@ def no_config_chain_pipeline():
     def return_hello_world(_):
         return "Hello World"
 
-    return return_hello_world(return_foo())
+    return_hello_world(return_foo())
 
 
 @pipeline
@@ -434,7 +423,7 @@ def pipeline_with_enum_config():
     def takes_an_enum(_context):
         pass
 
-    return takes_an_enum()
+    takes_an_enum()
 
 
 @pipeline
@@ -443,7 +432,7 @@ def naughty_programmer_pipeline():
     def throw_a_thing():
         raise Exception("bad programmer, bad")
 
-    return throw_a_thing()
+    throw_a_thing()
 
 
 @pipeline
@@ -463,7 +452,7 @@ def pipeline_with_invalid_definition_error():
     def fail_subset(_, some_input):
         return some_input
 
-    return fail_subset(one())
+    fail_subset(one())
 
 
 @resource(config_schema=Field(Int))
@@ -510,7 +499,7 @@ def multi_mode_with_resources():
     def apply_to_three(context):
         return context.resources.op(3)
 
-    return apply_to_three()
+    apply_to_three()
 
 
 @resource(config_schema=Field(Int, is_required=False))
@@ -570,7 +559,7 @@ def multi_mode_with_loggers():
         context.log.critical("OMG!")
         return 6
 
-    return return_six()
+    return_six()
 
 
 @pipeline
@@ -595,7 +584,7 @@ def composites_pipeline():
     def div_four(num):
         return div_two.alias("div_2")(div_two.alias("div_1")(num))
 
-    return div_four(add_four())
+    div_four(add_four())
 
 
 @pipeline
@@ -761,7 +750,7 @@ def tagged_pipeline():
     def simple_solid():
         return "Hello"
 
-    return simple_solid()
+    simple_solid()
 
 
 @pipeline
@@ -800,7 +789,7 @@ def retry_multi_input_early_terminate_pipeline():
         return input_one + input_two
 
     step_one = return_one()
-    return sum_inputs(input_one=get_input_one(step_one), input_two=get_input_two(step_one))
+    sum_inputs(input_one=get_input_one(step_one), input_two=get_input_two(step_one))
 
 
 def get_retry_multi_execution_params(graphql_context, should_fail, retry_id=None):
@@ -870,7 +859,7 @@ def define_schedules():
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
     )
     def partition_based_decorator(_date):
@@ -878,7 +867,7 @@ def define_schedules():
 
     @daily_schedule(
         pipeline_name="multi_mode_with_loggers",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
         mode="foo_mode",
     )
@@ -887,7 +876,7 @@ def define_schedules():
 
     @hourly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
         solid_selection=["return_foo"],
     )
@@ -896,7 +885,7 @@ def define_schedules():
 
     @daily_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=2),
+        start_date=today_at_midnight() - datetime.timedelta(days=2),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=3)).time(),
         solid_selection=["return_foo"],
     )
@@ -905,7 +894,7 @@ def define_schedules():
 
     @monthly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=100),
+        start_date=(today_at_midnight() - datetime.timedelta(days=100)).replace(day=1),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=4)).time(),
         solid_selection=["return_foo"],
     )
@@ -914,7 +903,7 @@ def define_schedules():
 
     @weekly_schedule(
         pipeline_name="no_config_chain_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=50),
+        start_date=today_at_midnight() - datetime.timedelta(days=50),
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=5)).time(),
         solid_selection=["return_foo"],
     )
@@ -924,7 +913,7 @@ def define_schedules():
     # Schedules for testing the user error boundary
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
         should_execute=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def should_execute_error_schedule(_date):
@@ -932,7 +921,7 @@ def define_schedules():
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
         tags_fn_for_date=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def tags_error_schedule(_date):
@@ -940,7 +929,7 @@ def define_schedules():
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
-        start_date=datetime.datetime.now() - datetime.timedelta(days=1),
+        start_date=today_at_midnight() - datetime.timedelta(days=1),
     )
     def run_config_error_schedule(_date):
         return asdf  # pylint: disable=undefined-variable
@@ -1018,12 +1007,12 @@ def define_partitions():
     return [integer_set, enum_set, chained_partition_set]
 
 
-def define_executables():
-    @executable(pipeline_name="no_config_pipeline")
-    def executable_no_config(_):
+def define_jobs():
+    @job(pipeline_name="no_config_pipeline")
+    def job_no_config(_):
         return {"storage": {"filesystem": {}}}
 
-    return [executable_no_config]
+    return [job_no_config]
 
 
 @pipeline
@@ -1043,7 +1032,7 @@ def chained_failure_pipeline():
     def after_failure(_):
         return "world"
 
-    return after_failure(conditionally_fail(always_succeed()))
+    after_failure(conditionally_fail(always_succeed()))
 
 
 @repository
@@ -1091,5 +1080,5 @@ def test_repo():
         ]
         + define_schedules()
         + define_partitions()
-        + define_executables()
+        + define_jobs()
     )
