@@ -1,14 +1,13 @@
+from dagster.core.scheduler.scheduler import ScheduleStatus
 from dagster_graphql.test.utils import (
     execute_dagster_graphql,
     infer_repository_selector,
     infer_schedule_selector,
+    main_repo_location_name,
+    main_repo_name,
 )
 
-from dagster.core.scheduler.scheduler import ScheduleStatus
-
-from .setup import main_repo_location_name, main_repo_name
-
-GET_SCHEDULE_STATES_QUERY = '''
+GET_SCHEDULE_STATES_QUERY = """
 query ScheduleStateQuery($repositorySelector: RepositorySelector!) {
   scheduleStatesOrError(repositorySelector: $repositorySelector) {
     __typename
@@ -27,9 +26,9 @@ query ScheduleStateQuery($repositorySelector: RepositorySelector!) {
     }
   }
 }
-'''
+"""
 
-GET_SCHEDULE_STATES_WITHOUT_DEFINITIONS_QUERY = '''
+GET_SCHEDULE_STATES_WITHOUT_DEFINITIONS_QUERY = """
 query ScheduleStateQuery($repositorySelector: RepositorySelector!) {
   scheduleStatesOrError(repositorySelector: $repositorySelector, withNoScheduleDefinition: true) {
     __typename
@@ -48,9 +47,9 @@ query ScheduleStateQuery($repositorySelector: RepositorySelector!) {
     }
   }
 }
-'''
+"""
 
-GET_SCHEDULE_DEFINITIONS_QUERY = '''
+GET_SCHEDULE_DEFINITIONS_QUERY = """
 query ScheduleDefinitionsQuery($repositorySelector: RepositorySelector!) {
   scheduleDefinitionsOrError(repositorySelector: $repositorySelector) {
     __typename
@@ -75,9 +74,9 @@ query ScheduleDefinitionsQuery($repositorySelector: RepositorySelector!) {
     }
   }
 }
-'''
+"""
 
-GET_SCHEDULE_DEFINITION = '''
+GET_SCHEDULE_DEFINITION = """
 query getScheduleDefinition($scheduleSelector: ScheduleSelector!) {
   scheduleDefinitionOrError(scheduleSelector: $scheduleSelector) {
     __typename
@@ -93,9 +92,9 @@ query getScheduleDefinition($scheduleSelector: ScheduleSelector!) {
     }
   }
 }
-'''
+"""
 
-RECONCILE_SCHEDULER_STATE_QUERY = '''
+RECONCILE_SCHEDULER_STATE_QUERY = """
 mutation(
   $repositorySelector: RepositorySelector!
 ) {
@@ -111,10 +110,10 @@ mutation(
       }
     }
 }
-'''
+"""
 
 
-START_SCHEDULES_QUERY = '''
+START_SCHEDULES_QUERY = """
 mutation(
   $scheduleSelector: ScheduleSelector!
 ) {
@@ -128,20 +127,21 @@ mutation(
     }
     ... on ScheduleStateResult {
       scheduleState {
+        scheduleOriginId
         status
       }
     }
   }
 }
-'''
+"""
 
 
-STOP_SCHEDULES_QUERY = '''
+STOP_SCHEDULES_QUERY = """
 mutation(
-  $scheduleSelector: ScheduleSelector!
+  $scheduleOriginId: String!
 ) {
   stopRunningSchedule(
-    scheduleSelector: $scheduleSelector,
+    scheduleOriginId: $scheduleOriginId,
   ) {
     ... on PythonError {
       message
@@ -155,7 +155,7 @@ mutation(
     }
   }
 }
-'''
+"""
 
 
 def default_execution_params():
@@ -169,59 +169,62 @@ def default_execution_params():
 def test_get_schedule_definitions_for_repository(graphql_context):
     selector = infer_repository_selector(graphql_context)
     result = execute_dagster_graphql(
-        graphql_context, GET_SCHEDULE_DEFINITIONS_QUERY, variables={'repositorySelector': selector},
+        graphql_context, GET_SCHEDULE_DEFINITIONS_QUERY, variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['scheduleDefinitionsOrError']
-    assert result.data['scheduleDefinitionsOrError']['__typename'] == 'ScheduleDefinitions'
+    assert result.data["scheduleDefinitionsOrError"]
+    assert result.data["scheduleDefinitionsOrError"]["__typename"] == "ScheduleDefinitions"
 
     external_repository = graphql_context.get_repository_location(
         main_repo_location_name()
     ).get_repository(main_repo_name())
 
-    results = result.data['scheduleDefinitionsOrError']['results']
+    results = result.data["scheduleDefinitionsOrError"]["results"]
     assert len(results) == len(external_repository.get_external_schedules())
 
     for schedule in results:
-        if schedule['name'] == 'run_config_error_schedule':
-            assert schedule['runConfigOrError']['__typename'] == 'PythonError'
-        elif schedule['name'] == 'invalid_config_schedule':
+        if (
+            schedule["name"] == "run_config_error_schedule"
+            or schedule["name"] == "tags_error_schedule"
+        ):
+            assert schedule["runConfigOrError"]["__typename"] == "PythonError"
+        elif schedule["name"] == "invalid_config_schedule":
             assert (
-                schedule['runConfigOrError']['yaml']
-                == 'solids:\n  takes_an_enum:\n    config: invalid\n'
+                schedule["runConfigOrError"]["yaml"]
+                == "solids:\n  takes_an_enum:\n    config: invalid\n"
             )
         else:
-            assert schedule['runConfigOrError']['yaml'] == 'storage:\n  filesystem: {}\n'
+            assert schedule["runConfigOrError"]["yaml"] == "storage:\n  filesystem: {}\n"
 
 
 def test_get_schedule_states_for_repository(graphql_context):
     selector = infer_repository_selector(graphql_context)
     result = execute_dagster_graphql(
-        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={'repositorySelector': selector},
+        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['scheduleStatesOrError']
-    assert result.data['scheduleStatesOrError']['__typename'] == 'ScheduleStates'
+    assert result.data["scheduleStatesOrError"]
+    assert result.data["scheduleStatesOrError"]["__typename"] == "ScheduleStates"
 
     # Since we haven't run reconcile yet, there should be no states in storage
-    results = result.data['scheduleStatesOrError']['results']
+    results = result.data["scheduleStatesOrError"]["results"]
     assert len(results) == 0
 
 
 def test_get_schedule_state_with_for_repository_not_reconciled(graphql_context):
     selector = infer_repository_selector(graphql_context)
     result = execute_dagster_graphql(
-        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={'repositorySelector': selector},
+        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['scheduleStatesOrError']
-    assert result.data['scheduleStatesOrError']['__typename'] == 'ScheduleStates'
+    assert result.data["scheduleStatesOrError"]
+    assert result.data["scheduleStatesOrError"]["__typename"] == "ScheduleStates"
 
     # Since we haven't run reconcile yet, there should be no states in storage
-    results = result.data['scheduleStatesOrError']['results']
+    results = result.data["scheduleStatesOrError"]["results"]
     assert len(results) == 0
 
 
@@ -234,18 +237,18 @@ def test_get_schedule_states_for_repository_after_reconcile(graphql_context):
     graphql_context.instance.reconcile_scheduler_state(external_repository)
 
     result = execute_dagster_graphql(
-        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={'repositorySelector': selector},
+        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['scheduleStatesOrError']
-    assert result.data['scheduleStatesOrError']['__typename'] == 'ScheduleStates'
+    assert result.data["scheduleStatesOrError"]
+    assert result.data["scheduleStatesOrError"]["__typename"] == "ScheduleStates"
 
-    results = result.data['scheduleStatesOrError']['results']
+    results = result.data["scheduleStatesOrError"]["results"]
     assert len(results) == len(external_repository.get_external_schedules())
 
     for schedule_state in results:
-        assert schedule_state['status'] == ScheduleStatus.STOPPED.value
+        assert schedule_state["status"] == ScheduleStatus.STOPPED.value
 
 
 def test_get_schedule_states_for_repository_after_reconcile_using_mutation(graphql_context):
@@ -258,26 +261,26 @@ def test_get_schedule_states_for_repository_after_reconcile_using_mutation(graph
     result = execute_dagster_graphql(
         graphql_context,
         RECONCILE_SCHEDULER_STATE_QUERY,
-        variables={'repositorySelector': selector},
+        variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['reconcileSchedulerState']
-    assert result.data['reconcileSchedulerState']['message'] == "Success"
+    assert result.data["reconcileSchedulerState"]
+    assert result.data["reconcileSchedulerState"]["message"] == "Success"
 
     result = execute_dagster_graphql(
-        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={'repositorySelector': selector},
+        graphql_context, GET_SCHEDULE_STATES_QUERY, variables={"repositorySelector": selector},
     )
 
     assert result.data
-    assert result.data['scheduleStatesOrError']
-    assert result.data['scheduleStatesOrError']['__typename'] == 'ScheduleStates'
+    assert result.data["scheduleStatesOrError"]
+    assert result.data["scheduleStatesOrError"]["__typename"] == "ScheduleStates"
 
-    results = result.data['scheduleStatesOrError']['results']
+    results = result.data["scheduleStatesOrError"]["results"]
     assert len(results) == len(external_repository.get_external_schedules())
 
     for schedule_state in results:
-        assert schedule_state['status'] == ScheduleStatus.STOPPED.value
+        assert schedule_state["status"] == ScheduleStatus.STOPPED.value
 
 
 def test_get_schedule_states_for_repository_with_removed_schedule_definitions(graphql_context):
@@ -291,12 +294,12 @@ def test_get_schedule_states_for_repository_with_removed_schedule_definitions(gr
     result = execute_dagster_graphql(
         graphql_context,
         GET_SCHEDULE_STATES_WITHOUT_DEFINITIONS_QUERY,
-        variables={'repositorySelector': selector},
+        variables={"repositorySelector": selector},
     )
 
-    assert result.data['scheduleStatesOrError']
-    assert result.data['scheduleStatesOrError']['__typename'] == 'ScheduleStates'
-    results = result.data['scheduleStatesOrError']['results']
+    assert result.data["scheduleStatesOrError"]
+    assert result.data["scheduleStatesOrError"]["__typename"] == "ScheduleStates"
+    results = result.data["scheduleStatesOrError"]["results"]
     assert len(results) == 0
 
 
@@ -309,24 +312,26 @@ def test_start_and_stop_schedule(graphql_context):
     graphql_context.instance.reconcile_scheduler_state(external_repository)
 
     schedule_selector = infer_schedule_selector(
-        graphql_context, 'no_config_pipeline_hourly_schedule'
+        graphql_context, "no_config_pipeline_hourly_schedule"
     )
 
     # Start a single schedule
     start_result = execute_dagster_graphql(
-        graphql_context, START_SCHEDULES_QUERY, variables={'scheduleSelector': schedule_selector},
+        graphql_context, START_SCHEDULES_QUERY, variables={"scheduleSelector": schedule_selector},
     )
     assert (
-        start_result.data['startSchedule']['scheduleState']['status']
+        start_result.data["startSchedule"]["scheduleState"]["status"]
         == ScheduleStatus.RUNNING.value
     )
 
+    schedule_origin_id = start_result.data["startSchedule"]["scheduleState"]["scheduleOriginId"]
+
     # Stop a single schedule
     stop_result = execute_dagster_graphql(
-        graphql_context, STOP_SCHEDULES_QUERY, variables={'scheduleSelector': schedule_selector},
+        graphql_context, STOP_SCHEDULES_QUERY, variables={"scheduleOriginId": schedule_origin_id},
     )
     assert (
-        stop_result.data['stopRunningSchedule']['scheduleState']['status']
+        stop_result.data["stopRunningSchedule"]["scheduleState"]["status"]
         == ScheduleStatus.STOPPED.value
     )
 
@@ -341,11 +346,11 @@ def test_get_single_schedule_definition(graphql_context):
         ).get_repository(main_repo_name()),
     )
 
-    schedule_selector = infer_schedule_selector(context, 'partition_based_multi_mode_decorator')
+    schedule_selector = infer_schedule_selector(context, "partition_based_multi_mode_decorator")
     result = execute_dagster_graphql(
-        context, GET_SCHEDULE_DEFINITION, variables={'scheduleSelector': schedule_selector}
+        context, GET_SCHEDULE_DEFINITION, variables={"scheduleSelector": schedule_selector}
     )
 
     assert result.data
-    assert result.data['scheduleDefinitionOrError']['__typename'] == 'ScheduleDefinition'
-    assert result.data['scheduleDefinitionOrError']['partitionSet']
+    assert result.data["scheduleDefinitionOrError"]["__typename"] == "ScheduleDefinition"
+    assert result.data["scheduleDefinitionOrError"]["partitionSet"]
