@@ -21,9 +21,6 @@ def test_sync_run_launcher_from_configurable_class():
 
 
 def test_sync_run_launcher_run():
-    external_repo = get_main_external_repo()
-    external_pipeline = external_repo.get_full_external_pipeline("noop_pipeline")
-
     with seven.TemporaryDirectory() as temp_dir:
         instance = DagsterInstance.local_temp(
             temp_dir,
@@ -35,6 +32,9 @@ def test_sync_run_launcher_run():
             },
         )
 
+        external_repo = get_main_external_repo(instance)
+        external_pipeline = external_repo.get_full_external_pipeline("noop_pipeline")
+
         run = create_run_for_test(instance=instance, pipeline_name=external_pipeline.name)
 
         run = instance.run_launcher.launch_run(
