@@ -4,22 +4,11 @@ import time
 from contextlib import contextmanager
 
 from click.testing import CliRunner
-from dagster_graphql.cli import ui
-
-from dagster import (
-    InputDefinition,
-    Int,
-    OutputDefinition,
-    ScheduleDefinition,
-    lambda_solid,
-    pipeline,
-    repository,
-    seven,
-    solid,
-)
+from dagster import seven
 from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.core.test_utils import instance_for_test_tempdir
 from dagster.utils import file_relative_path
+from dagster_graphql.cli import ui
 
 
 @contextmanager
@@ -37,53 +26,6 @@ def dagster_cli_runner():
             yield CliRunner(env={"DAGSTER_HOME": dagster_home_temp})
 
 
-@lambda_solid(input_defs=[InputDefinition("num", Int)], output_def=OutputDefinition(Int))
-def add_one(num):
-    return num + 1
-
-
-@lambda_solid(input_defs=[InputDefinition("num", Int)], output_def=OutputDefinition(Int))
-def mult_two(num):
-    return num * 2
-
-
-@pipeline
-def math():
-    mult_two(add_one())
-
-
-@solid(config_schema={"gimme": str})
-def needs_config(context):
-    return context.solid_config["gimme"]
-
-
-@lambda_solid
-def no_config():
-    return "ok"
-
-
-@pipeline
-def subset_test():
-    no_config()
-    needs_config()
-
-
-def define_schedules():
-    math_hourly_schedule = ScheduleDefinition(
-        name="math_hourly_schedule",
-        cron_schedule="0 0 * * *",
-        pipeline_name="math",
-        run_config={"solids": {"add_one": {"inputs": {"num": {"value": 123}}}}},
-    )
-
-    return [math_hourly_schedule]
-
-
-@repository
-def test():
-    return [math, subset_test] + define_schedules()
-
-
 def test_basic_introspection():
     query = "{ __schema { types { name } } }"
 
@@ -118,7 +60,7 @@ def test_basic_variables():
         { ... on Pipeline { name } }
     }
     """
-    variables = '{"pipelineName": "math", "repositoryName": "test", "repositoryLocationName": "<<in_process>>"}'
+    variables = '{"pipelineName": "math", "repositoryName": "test", "repositoryLocationName": "test_cli_location"}'
     workspace_path = file_relative_path(__file__, "./cli_test_workspace.yaml")
 
     with dagster_cli_runner() as runner:
@@ -161,7 +103,7 @@ def test_start_execution_text():
         {
             "executionParams": {
                 "selector": {
-                    "repositoryLocationName": "<<in_process>>",
+                    "repositoryLocationName": "test_cli_location",
                     "repositoryName": "test",
                     "pipelineName": "math",
                 },
@@ -196,7 +138,7 @@ def test_start_execution_file():
             "executionParams": {
                 "selector": {
                     "pipelineName": "math",
-                    "repositoryLocationName": "<<in_process>>",
+                    "repositoryLocationName": "test_cli_location",
                     "repositoryName": "test",
                 },
                 "runConfigData": {"solids": {"add_one": {"inputs": {"num": {"value": 123}}}}},
@@ -236,7 +178,7 @@ def test_start_execution_save_output():
         {
             "executionParams": {
                 "selector": {
-                    "repositoryLocationName": "<<in_process>>",
+                    "repositoryLocationName": "test_cli_location",
                     "repositoryName": "test",
                     "pipelineName": "math",
                 },
@@ -283,7 +225,7 @@ def test_start_execution_predefined():
         {
             "executionParams": {
                 "selector": {
-                    "repositoryLocationName": "<<in_process>>",
+                    "repositoryLocationName": "test_cli_location",
                     "repositoryName": "test",
                     "pipelineName": "math",
                 },
@@ -314,7 +256,7 @@ def test_logs_in_start_execution_predefined():
         {
             "executionParams": {
                 "selector": {
-                    "repositoryLocationName": "<<in_process>>",
+                    "repositoryLocationName": "test_cli_location",
                     "repositoryName": "test",
                     "pipelineName": "math",
                 },
@@ -361,34 +303,3 @@ def test_logs_in_start_execution_predefined():
 
 def _is_done(instance, run_id):
     return instance.has_run(run_id) and instance.get_run_by_id(run_id).is_finished
-
-
-def test_solid_selection():
-    variables = seven.json.dumps(
-        {
-            "executionParams": {
-                "mode": "default",
-                "runConfigData": {},
-                "selector": {
-                    "repositoryLocationName": "<<in_process>>",
-                    "repositoryName": "test",
-                    "pipelineName": "subset_test",
-                    "solidSelection": ["no_config"],
-                },
-                "executionMetadata": {"runId": "1234"},
-                "stepKeys": ["no_config.compute"],
-            },
-        }
-    )
-    workspace_path = file_relative_path(__file__, "./cli_test_workspace.yaml")
-
-    with dagster_cli_runner() as runner:
-        result = runner.invoke(ui, ["-w", workspace_path, "-v", variables, "-p", "executePlan"])
-
-        assert result.exit_code == 0
-
-        try:
-            result_data = json.loads(result.output.strip("\n").split("\n")[-1])
-            assert result_data["data"]["executePlan"]["__typename"] == "ExecutePlanSuccess"
-        except Exception as e:
-            raise Exception("Failed with {} Exception: {}".format(result.output, e))
